==> yyjson-0.11.1.tar.gz: yyjson-0.11.1/doc/doxygen/html/search/all_10.js <==
var searchData=
[
  ['features_0',['Features',['../index.html#features',1,'']]],
  ['file_1',['file',['../api.html#read-json-from-file',1,'Read JSON from file'],['../api.html#write-json-to-file',1,'Write JSON to file']]],
  ['file_20pointer_2',['file pointer',['../api.html#read-json-from-file-pointer',1,'Read JSON from file pointer'],['../api.html#write-json-to-file-pointer',1,'Write JSON to file pointer']]],
  ['file_20with_20options_3',['file with options',['../index.html#read-json-file-with-options',1,'Read JSON file with options'],['../index.html#write-json-file-with-options',1,'Write JSON file with options']]],
  ['fixed_4',['Fixed',['../md__c_h_a_n_g_e_l_o_g.html#fixed',1,'Fixed'],['../md__c_h_a_n_g_e_l_o_g.html#fixed-1',1,'Fixed'],['../md__c_h_a_n_g_e_l_o_g.html#fixed-2',1,'Fixed'],['../md__c_h_a_n_g_e_l_o_g.html#fixed-3',1,'Fixed'],['../md__c_h_a_n_g_e_l_o_g.html#fixed-4',1,'Fixed'],['../md__c_h_a_n_g_e_l_o_g.html#fixed-5',1,'Fixed'],['../md__c_h_a_n_g_e_l_o_g.html#fixed-6',1,'Fixed'],['../md__c_h_a_n_g_e_l_o_g.html#fixed-7',1,'Fixed'],['../md__c_h_a_n_g_e_l_o_g.html#fixed-8',1,'Fixed'],['../md__c_h_a_n_g_e_l_o_g.html#fixed-9',1,'Fixed'],['../md__c_h_a_n_g_e_l_o_g.html#fixed-10',1,'Fixed'],['../md__c_h_a_n_g_e_l_o_g.html#fixed-11',1,'Fixed']]],
  ['flag_5',['flag',['../api.html#reader-flag',1,'Reader flag'],['../api.html#writer-flag',1,'Writer flag']]],
  ['for_20better_20performance_20yyjson_20prefers_3a_6',['For better performance, yyjson prefers:',['../index.html#for-better-performance-yyjson-prefers',1,'']]],
  ['for_20immutable_20mutable_20data_7',['API for immutable/mutable data',['../api.html#api-for-immutablemutable-data',1,'']]],
  ['for_20incremental_20reading_8',['for incremental reading',['../api.html#create-the-state-for-incremental-reading',1,'Create the state for incremental reading'],['../api.html#free-the-state-used-for-incremental-reading',1,'Free the state used for incremental reading']]],
  ['for_20multiple_20json_9',['Single allocator for multiple JSON',['../api.html#single-allocator-for-multiple-json',1,'']]],
  ['for_20string_10',['API for string',['../api.html#api-for-string',1,'']]],
  ['for_20v1_200_11',['TODO for v1.0',['../index.html#todo-for-v10',1,'']]],
  ['free_12',['free',['../yyjson_8h.html#a2c770ff93f0f331bd60076eecd93661e',1,'yyjson_alc']]],
  ['free_20the_20state_20used_20for_20incremental_20reading_13',['Free the state used for incremental reading',['../api.html#free-the-state-used-for-incremental-reading',1,'']]],
  ['from_20file_14',['Read JSON from file',['../api.html#read-json-from-file',1,'']]],
  ['from_20file_20pointer_15',['Read JSON from file pointer',['../api.html#read-json-from-file-pointer',1,'']]],
  ['from_20string_16',['Read JSON from string',['../api.html#read-json-from-string',1,'']]]
];

==> yyjson-0.12.0.tar.gz: yyjson-0.12.0/doc/doxygen/html/search/all_10.js <==
var searchData=
[
  ['features_0',['Features',['../index.html#features',1,'']]],
  ['file_1',['file',['../api.html#read-json-from-file',1,'Read JSON from file'],['../api.html#write-json-to-file',1,'Write JSON to file']]],
  ['file_20pointer_2',['file pointer',['../api.html#read-json-from-file-pointer',1,'Read JSON from file pointer'],['../api.html#write-json-to-file-pointer',1,'Write JSON to file pointer']]],
  ['file_20with_20options_3',['file with options',['../index.html#read-json-file-with-options',1,'Read JSON file with options'],['../index.html#write-json-file-with-options',1,'Write JSON file with options']]],
  ['fixed_4',['Fixed',['../md__c_h_a_n_g_e_l_o_g.html#fixed',1,'Fixed'],['../md__c_h_a_n_g_e_l_o_g.html#fixed-1',1,'Fixed'],['../md__c_h_a_n_g_e_l_o_g.html#fixed-2',1,'Fixed'],['../md__c_h_a_n_g_e_l_o_g.html#fixed-3',1,'Fixed'],['../md__c_h_a_n_g_e_l_o_g.html#fixed-4',1,'Fixed'],['../md__c_h_a_n_g_e_l_o_g.html#fixed-5',1,'Fixed'],['../md__c_h_a_n_g_e_l_o_g.html#fixed-6',1,'Fixed'],['../md__c_h_a_n_g_e_l_o_g.html#fixed-7',1,'Fixed'],['../md__c_h_a_n_g_e_l_o_g.html#fixed-8',1,'Fixed'],['../md__c_h_a_n_g_e_l_o_g.html#fixed-9',1,'Fixed'],['../md__c_h_a_n_g_e_l_o_g.html#fixed-10',1,'Fixed'],['../md__c_h_a_n_g_e_l_o_g.html#fixed-11',1,'Fixed']]],
  ['flag_5',['flag',['../api.html#reader-flag',1,'Reader flag'],['../api.html#writer-flag',1,'Writer flag']]],
  ['for_20better_20performance_20yyjson_20prefers_3a_6',['For better performance, yyjson prefers:',['../index.html#for-better-performance-yyjson-prefers',1,'']]],
  ['for_20immutable_20mutable_20data_7',['API for immutable/mutable data',['../api.html#api-for-immutablemutable-data',1,'']]],
  ['for_20incremental_20reading_8',['for incremental reading',['../api.html#create-the-state-for-incremental-reading',1,'Create the state for incremental reading'],['../api.html#free-the-state-used-for-incremental-reading',1,'Free the state used for incremental reading']]],
  ['for_20multiple_20json_9',['Single allocator for multiple JSON',['../api.html#single-allocator-for-multiple-json',1,'']]],
  ['for_20string_10',['API for string',['../api.html#api-for-string',1,'']]],
  ['for_20v1_200_11',['TODO for v1.0',['../index.html#todo-for-v10',1,'']]],
  ['free_12',['free',['../yyjson_8h.html#a2c770ff93f0f331bd60076eecd93661e',1,'yyjson_alc']]],
  ['free_20the_20state_20used_20for_20incremental_20reading_13',['Free the state used for incremental reading',['../api.html#free-the-state-used-for-incremental-reading',1,'']]],
  ['from_20file_14',['Read JSON from file',['../api.html#read-json-from-file',1,'']]],
  ['from_20file_20pointer_15',['Read JSON from file pointer',['../api.html#read-json-from-file-pointer',1,'']]],
  ['from_20string_16',['Read JSON from string',['../api.html#read-json-from-string',1,'']]],
  ['function_17',['Number conversion function',['../api.html#number-conversion-function',1,'']]]
];
